import java.awt.*;

class mainform extends mform{
	public Frame fram;
	private void init(){
		fram = new Frame();
		fram.setLayout(new GridLayout(1,1));

		fram.add (this);
	}
	public mainform(String _id, String _titre){
		super(null,_id);
		init();
		setTitle (_titre);
	}
	public mainform(String _id){
		super (null,_id);
		init();
	}
	public void Popup(){
		// System.err.println ("Avant pack");
		fram.pack();
		// System.err.println ("Avant show");
		fram.show();
		// System.err.println ("Apres show");
	}
	public void setTitle(String title){
		fram.setTitle(title);
	}
	public void dispose(){
		fram.dispose();
	}
}

